@@ -11,10 +11,8 @@ class MarkovChain {
   unsigned int iteration;
 //  MCMCprogress* progressBar;
 
-  // States
-  std::vector<long> discreteStates;
-  std::vector<double> continuousStates;
-
+  virtual double applyTransitionKernel() = 0; // returns log posterior
+  void doNothing();
 public:
 //  MarkovChain() : iteration(0), progressBar(new MCMCprogress()) {}
   MarkovChain() : iteration(0) {}
@@ -35,9 +33,6 @@ public:
   // Getters
   double getLogPosterior() {return logPosterior;}
   unsigned int getIteration() {return iteration;}
-
-protected:
-  virtual double applyTransitionKernel() = 0; // returns log posterior
 };
 
 #endif
